@@ -41,7 +41,8 @@
 #' * [handler_ascii_alert]
 #' * [handler_debug]
 #'
-#' In the graphical user interface (GUI):
+#' In a graphical user interface (GUI):
+#' * [handler_rstudio]
 #' * [handler_tkprogressbar]
 #' * [handler_winprogressbar]
 #'
@@ -55,11 +56,15 @@
 #' In Shiny:
 #' * [withProgressShiny]
 #'
+#' Via notification systems:
+#' * [handler_ntfy]
+#' * [handler_notifier]
+#' * [handler_rpushbullet]
+#'
 #' @example incl/progressr-package.R
 #'
 #' @keywords programming iteration
 #'
-#' @docType package
 #' @aliases progressr-package
 #' @name progressr
-NULL
+"_PACKAGE"
